# Generated by roxygen2: do not edit by hand

S3method(cosine,data.frame)
S3method(cosine,default)
S3method(cosine,dgCMatrix)
S3method(cosine,matrix)
S3method(cosine,simple_triplet_matrix)
S3method(covar,data.frame)
S3method(covar,default)
S3method(covar,matrix)
S3method(pcor,data.frame)
S3method(pcor,default)
S3method(pcor,matrix)
S3method(sparsity,matrix)
S3method(sparsity,simple_triplet_matrix)
S3method(tcosine,data.frame)
S3method(tcosine,matrix)
S3method(tcovar,data.frame)
S3method(tcovar,matrix)
S3method(tpcor,data.frame)
S3method(tpcor,matrix)
export(cosine)
export(covar)
export(pcor)
export(scaler)
export(sparsity)
export(tcosine)
export(tcovar)
export(tpcor)
useDynLib(coop, R_co_mat, R_co_mat_pairwise, R_co_vecvec, R_co_sparse, R_sparsity_int, R_sparsity_dbl, R_csc_to_coo, R_fast_naomit, R_naomit_vecvec, R_scaler, R_check_badvals)
